@@ -196,6 +196,17 @@ def kp_matcher(doc): #[('vend', 'consider going', 1, 3), ('vp', 'consider going'
 	[tups.add( kp_span(doc,ibeg,iend, spacy.nlp.vocab[name].text) ) for name, ibeg,iend in kp_matcher.matcher(doc)] 
 	return tups
 
+# added 2022.7.25
+post_np_rules = { # after np is merged 
+"v_n_vbn": [[{"POS": 'VERB', "TAG": {"NOT_IN": ["VBN"]}},{"POS": {"IN": ["NOUN"]}}, {"TAG": {"IN": ["VBN"]}}]],   # leave the book opened 
+"v_n_adj": [[{"POS": 'VERB', "TAG": {"NOT_IN": ["VBN"]}},{"POS": {"IN": ["NOUN"]}}, {"POS": {"IN": ["ADJ"]}}]],
+} #for name, ibeg,iend in matcher(doc) : print(spacy.nlp.vocab[name].text, doc[ibeg:iend].text)
+def post_np_matcher(doc): 
+	if not hasattr(post_np_matcher, 'matcher'): 
+		post_np_matcher.matcher = Matcher(spacy.nlp.vocab)
+		[post_np_matcher.matcher.add(name, patterns,  greedy ='LONGEST') for name, patterns in post_np_rules.items() ]
+	return [(spacy.nlp.vocab[name].text,ibeg,iend) for name, ibeg,iend in post_np_matcher.matcher(doc)] 
+
 def new_matcher(patterns, name='pat'):
 	matcher = Matcher(spacy.nlp.vocab)
 	matcher.add(name, patterns, greedy ='LONGEST')
@@ -257,7 +268,7 @@ def parse_if(snt, prefix:str="bytes:", ttl:int=37200):
 def merge_np(doc):
 	with doc.retokenize() as retokenizer:
 		for np in doc.noun_chunks:
-			attrs = {"tag": np.root.tag, "dep": np.root.dep, "ent_type": "NP"}
+			attrs = {"tag": np.root.tag, "dep": np.root.dep, "ent_type": "NP", "lemma":doc[np.end-1].lemma} # , "lemma":doc[np.end-1].lemma | added 2022.7.26
 			retokenizer.merge(np, attrs=attrs) 
 	return doc
 
@@ -653,9 +664,10 @@ def dep_matcher(doc): #[('svx', [1, 0, 2])]
 
 [setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)			
 if __name__	== '__main__': 
-	doc = spacy.nlp("It is on the brink, and I am very happy, and I am angry with you.") 
-	#print ( kp_matcher(doc) ) 
-	print (parse("I love you."))
+	doc = spacy.nlp("It is on the brink, and I am very happy, and I leave these books opened.") 
+	merge_np(doc)
+	print ( post_np_matcher(doc) ) 
+	#print (parse("I love you."))
 	#print(sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", with_pid=True))
 #c:\users\zhang\appdata\local\programs\python\python38\lib\site-packages  
 #/home/ubuntu/.local/lib/python3.8/site-packages/en
\ No newline at end of file
