@@ -14,7 +14,7 @@ def walk(sid, doc):
 		,f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}",f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}",f"*:{t.pos_}:{t.tag_}", f"{t.lemma_.lower()}:{t.pos_}") for t in doc if not t.pos_ in ('PROPN','X', 'PUNCT') and t.is_alpha ]
 	for t in doc:
 		add( "#LEX", f"#{t.pos_}", f"#{t.tag_}",f"#{t.dep_}",) # book:VERB:VBG
-		if t.pos_ not in ("PROPN","PUNCT","SPACE"): 
+		if t.pos_ not in ("PROPN","PUNCT","SPACE") and t.is_alpha and t.head.is_alpha: #*:VERB:~punct:VERB:wink
 			reg(f"{t.lemma_.lower()}:{t.pos_}:{t.tag_}:{t.text.lower()}", sid) 
 			add(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}", f"*:{t.head.pos_}:{t.dep_}")
 			reg(f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}:{t.lemma_}", sid)
@@ -30,10 +30,16 @@ def walk(sid, doc):
 	for lem, pos, type, chunk in en.kp_matcher(doc): #brink:NOUN:pp:on the brink
 		add(f"{lem}:{pos}:{type}:{chunk}", f"{lem}:{pos}:{type}", f"*:{pos}:{type}", f"#{type}")
 		reg(f"{lem}:{pos}:{type}:{chunk}", sid)
-	for trpx, row in en.dep_matcher(doc): #[('svx', [1, 0, 2])]
+	for trpx, row in en.dep_matcher(doc): #[('svx', [1, 0, 2])] ## consider:VERB:vnpn:**** 
 		verbi = row[0] #consider:VERB:be_vbn_p:be considered as
 		add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:{trpx}", f"*:{doc[verbi].pos_}:{trpx}", f"#{trpx}") #consider:VERB:svx
 		reg(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:{trpx}", sid)
+		if trpx == 'sva' and doc[row[0]].lemma_ == 'be': # fate is sealed, added 2022.7.25
+			add(f"{doc[row[1]].lemma_}:{doc[row[1]].pos_}:sbea:{doc[row[2]].pos_}:{doc[row[2]].lemma_}", f"{doc[row[1]].lemma_}:{doc[row[1]].pos_}:sbea", f"*:{doc[row[1]].pos_}:sbea")
+			reg(f"{doc[row[1]].lemma_}:{doc[row[1]].pos_}:sbea:{doc[row[2]].pos_}:{doc[row[2]].lemma_}", sid)
+			add(f"{doc[row[2]].lemma_}:{doc[row[2]].pos_}:~sbea:{doc[row[1]].pos_}:{doc[row[1]].lemma_}", f"{doc[row[2]].lemma_}:{doc[row[2]].pos_}:~sbea", f"*:{doc[row[2]].pos_}:~sbea")
+			reg(f"{doc[row[2]].lemma_}:{doc[row[2]].pos_}:~sbea:{doc[row[1]].pos_}:{doc[row[1]].lemma_}", sid)
+
 	# last to be called, since NP is merged
 	for row in en.verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
 		if len(row) == 4: 
@@ -42,6 +48,11 @@ def walk(sid, doc):
 				add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}") #consider:VERB:verbnet:NP V S_ING
 				reg(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}", sid)
 
+	for name,ibeg,iend in en.post_np_matcher(doc): #added 2022.7.25
+		if name in ('v_n_vbn','v_n_adj'): 
+			add(f"{doc[ibeg].lemma_}:{doc[ibeg].pos_}:{name}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}", f"{doc[ibeg].lemma_}:{doc[ibeg].pos_}:{name}", f"*:{doc[ibeg].pos_}:{name}")
+			reg(f"{doc[ibeg].lemma_}:{doc[ibeg].pos_}:{name}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}", sid)
+
 def mysql(dbfile, host='127.0.0.1', port=3307, cutoff=0):  
 	''' clec.spacybs -> mysql:kpsi/clec,clec_snt , 2022.7.20 '''
 	import pymysql
@@ -96,25 +107,8 @@ def kpyes(dbfile, host='127.0.0.1', port=3309):
 		my_conn.commit()
 	print ("finished submitting:", dbfile, flush=True) 
 
-def tsv(dbfile, cutoff=1):  
-	''' bnc.spacybs -> bnc.si.tsv, bnc.snt.tsv ,  commonly large file, so filtered with cutoff '''
-	print ("started index:", dbfile, flush=True)
-	name = dbfile.lower().split('.')[0]
-	fire.si = Counter()
-	with open (f"{name}.tsv.snt", "w", encoding='UTF-8') as fw:
-		for rowid, snt, doc in Spacybs(dbfile).docs() : #for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
-			try: #doc =  spacy.frombs(bs)
-				terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','prep')]) 
-				fw.write(f"{rowid}\t{snt}\t{terms}\n")
-				walk(doc)
-			except Exception as e:
-				print ("ex:", e, rowid, snt)
-	with open (f"{name}.tsv.si", "w", encoding='UTF-8') as fw:
-		[ fw.write(f"{k}\t{v}\n") for k,v in fire.si.items() if v > cutoff ] 
-	print ("finished submitting:", dbfile, flush=True) 
-
-def batch(names="qdu,gzjc,gaokao,clec,dic"):
-	''' batch model, --names qdu,gzjc,gaokao,clec,dic '''
+def batch(names="qdu,gzjc,gaokao,clec"):
+	''' batch model, --names qdu,gzjc,gaokao,clec '''
 	[mysql(f"{name}.spacybs") for name in names.strip().split(',')]
 
 def trp(dbfile, cutoff=1):  
@@ -137,7 +131,7 @@ def dump(name, port=3309):
 	os.remove(f"{name}.sql.gz") if os.path.exists(f"{name}.sql.gz") else None 
 	os.system(f"mysqldump -uroot -pcikuutest! --port {port} --host=127.0.0.1 kpsi {name} {name}_snt --result-file={name}.sql")
 	os.system(f"gzip {name}.sql")
-	os.system(f"sshpass -p Cikuutest1 scp {name}.sql.gz ubuntu@lab.jukuu.com:/ftp")
+	#os.system(f"sshpass -p Cikuutest1 scp {name}.sql.gz ubuntu@lab.jukuu.com:/ftp")
 
 def load(name, port=3307): 
 	''' load twit --port 3307 @ lab.jukuu.com '''
@@ -146,10 +140,9 @@ def load(name, port=3307):
 	os.system(f"mysql -uroot -pcikuutest! -h 127.0.0.1 --port {port} kpsi  < {name}.sql")
 
 if __name__	== '__main__':
-	fire.Fire({"mysql":mysql, "tsv":tsv, "batch":batch, 'trp':trp , 'kpyes':kpyes, "dump":dump, "load":load})
+	fire.Fire({"mysql":mysql, "batch":batch, 'trp':trp , 'kpyes':kpyes, "dump":dump, "load":load})
 
 '''
-
 mysqldump -uroot -pcikuutest! --port 3307 --host=172.18.0.1 kpsi word_attr --result-file=word_attr.sql
 
 docker run -d --restart=always --name=kpsi --env='MYSQL_ROOT_PASSWORD=cikuutest!' --volume=/data/mariadb-mysi:/var/lib/mysql -p 3307:3306 mariadb --max_allowed_packet=100M --max_connections=1000 --disable-log-bin --innodb_file_per_table=1  --read_buffer_size=64M --read_rnd_buffer_size=64M --join_buffer_size=16M --tmp_table_size=512M
@@ -221,4 +214,21 @@ def submit(cursor): # NOT used
 			cursor.execute(f"INSERT INTO {name}(s,i) VALUES ('{k}', {v}) ON DUPLICATE KEY UPDATE i = i + {v}")
 	print ( len(fire.si), flush=True)
 	fire.si.clear()
+
+def tsv(dbfile, cutoff=1):  
+	# bnc.spacybs -> bnc.si.tsv, bnc.snt.tsv ,  commonly large file, so filtered with cutoff
+	print ("started index:", dbfile, flush=True)
+	name = dbfile.lower().split('.')[0]
+	fire.si = Counter()
+	with open (f"{name}.tsv.snt", "w", encoding='UTF-8') as fw:
+		for rowid, snt, doc in Spacybs(dbfile).docs() : #for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+			try: #doc =  spacy.frombs(bs)
+				terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','prep')]) 
+				fw.write(f"{rowid}\t{snt}\t{terms}\n")
+				walk(doc)
+			except Exception as e:
+				print ("ex:", e, rowid, snt)
+	with open (f"{name}.tsv.si", "w", encoding='UTF-8') as fw:
+		[ fw.write(f"{k}\t{v}\n") for k,v in fire.si.items() if v > cutoff ] 
+	print ("finished submitting:", dbfile, flush=True) 
 '''
\ No newline at end of file
