@@ -352,7 +352,7 @@ def lempos_type(doc):  # cp from attach, 2022.6.20, to be used in ES indexing  |
 			for name, ibeg,iend in matchers['vend'](doc)]
 		[ ssv[f"vpg-{ibeg}"].update ({"type":"vpg","lempos":doc[ibeg+1].lemma_+"_" + doc[ibeg+1].pos_,"chunk":vp_span(doc,ibeg,iend)})
 			for name, ibeg,iend in matchers['vpg'](doc)]
-		[ ssv[f"svo-{doc[x[0]].i}"].update ({"type":"svo", "chunk":f"{doc[x[1]].lemma_} {doc[x[0]].lemma_} {doc[x[2]].lemma_}", "lempos":doc[x[0]].lemma_ + "/VERB", }) 
+		[ ssv[f"svo-{doc[x[0]].i}"].update ({"type":"svo", "chunk":f"{doc[x[1]].lemma_} {doc[x[0]].lemma_} {doc[x[2]].lemma_}", "lempos":doc[x[0]].lemma_ + "_VERB", }) 
 			for name, x in depmatchers['svo'](doc) ]
 		[ ssv[f"sva-{doc[x[0]].i}"].update ({"type":"sva","lempos":doc[x[0]].lemma_ +"_VERB","chunk":f"{doc[x[1]].lemma_} {doc[x[0]].lemma_} {doc[x[2]].lemma_}"})
 			for name, x in depmatchers['sva'](doc) ]
