@@ -78,13 +78,13 @@ def save_ssi(idxname, suffix, ssi, dic):
 		print( f"saved: {idxname}.{suffix}, \t using: ", time.time() - start, flush=True)
 
 class ES(object):
-	def __init__(self, eshost='127.0.0.1',esport=9200): 
-		self.host = eshost # to be removed later 
-		self.port = esport 
-		self.es	  = Elasticsearch([ f"http://{eshost}:{esport}" ])  
-		requests.eshost	= eshost
-		requests.esport	= esport
-		requests.es		= Elasticsearch([ f"http://{requests.eshost}:{requests.esport}" ])  
+	def __init__(self, host='127.0.0.1',port=9200): 
+		self.host = host # to be removed later 
+		self.port = port 
+		self.es	  = Elasticsearch([ f"http://{host}:{port}" ])  
+		requests.eshost	= host
+		requests.esport	= port
+		requests.es		= Elasticsearch([ f"http://{requests.host}:{requests.port}" ])  
 
 	def list(self): 
 		''' list current index, show tables '''
@@ -195,6 +195,7 @@ class ES(object):
 		self.es.indices.create(index=idxname, body=config) #, body=snt_mapping
 		print(">>finished " + idxname )
 
+	def drop(self,idxname): self.es.indices.delete(index=idxname)
 	def clear(self,idxname): self.es.delete_by_query(index=idxname, body={"query": {"match_all": {}}})
 	def dumpid(self, idxname): [print (doc['_id'] + "\t" + json.dumps(doc['_source']))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
 	def dumpraw(self, idxname): [print (json.dumps(doc))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
