@@ -2,7 +2,7 @@
 # pip install numpy pandas click==7.1.2 requests_cache marisa_trie transformers torch numpy sentence_transformers wheel sacremoses lm-scorer-hashformers
 # sudo apt install python3.8-dev -y
 # pip install https://github.com/kpu/kenlm/archive/master.zip
-# pip install python-multipart textacy nltk
+# pip install python-multipart textacy nltk pyecharts
 from uvirun import *
 
 from fastapi import FastAPI, File, UploadFile,Form, Body,Request
@@ -25,6 +25,8 @@ from trans_fastapi import *
 from exchunk_fastapi	import *
 from nltk_fastapi	import *
 from hnswlib_fastapi	import *
+from kpsi_fastapi	import *
+from echart_fastapi	import *
 
 #if os.getenv('eshost','') : from es_fastapi import * 
 if os.getenv('rhost','') : from uviredis import * 
